==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/FirewallPolicyFirewallPolicyStatelessCustomActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property actionDefinition A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
 * @property actionName A friendly name of the custom action.
 */
public data class FirewallPolicyFirewallPolicyStatelessCustomActionArgs(
    public val actionDefinition:
    Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>,
    public val actionName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs> {
    override fun toJava():
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs =
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs.builder()
            .actionDefinition(actionDefinition.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .actionName(actionName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirewallPolicyFirewallPolicyStatelessCustomActionArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFirewallPolicyStatelessCustomActionArgsBuilder internal constructor() {
    private var actionDefinition:
        Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>? = null

    private var actionName: Output<String>? = null

    /**
     * @param value A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("qxergfqndfdqtklp")
    public suspend
    fun actionDefinition(`value`: Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>) {
        this.actionDefinition = value
    }

    /**
     * @param value A friendly name of the custom action.
     */
    @JvmName("onhylemsjrbowjpt")
    public suspend fun actionName(`value`: Output<String>) {
        this.actionName = value
    }

    /**
     * @param value A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("vpmutgexhglvnjnx")
    public suspend
    fun actionDefinition(`value`: FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionDefinition = mapped
    }

    /**
     * @param argument A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("oghcudsfmofbhltk")
    public suspend
    fun actionDefinition(argument: suspend FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped =
            FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.actionDefinition = mapped
    }

    /**
     * @param value A friendly name of the custom action.
     */
    @JvmName("rehrbqxfawxqyfhv")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionName = mapped
    }

    internal fun build(): FirewallPolicyFirewallPolicyStatelessCustomActionArgs =
        FirewallPolicyFirewallPolicyStatelessCustomActionArgs(
            actionDefinition = actionDefinition ?: throw PulumiNullFieldException("actionDefinition"),
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/FirewallPolicyFirewallPolicyStatelessCustomActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property actionDefinition A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
 * @property actionName A friendly name of the custom action.
 */
public data class FirewallPolicyFirewallPolicyStatelessCustomActionArgs(
    public val actionDefinition: Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>,
    public val actionName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs> {
    override fun toJava(): com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs =
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyStatelessCustomActionArgs.builder()
            .actionDefinition(actionDefinition.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .actionName(actionName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirewallPolicyFirewallPolicyStatelessCustomActionArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFirewallPolicyStatelessCustomActionArgsBuilder internal constructor() {
    private var actionDefinition:
        Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>? = null

    private var actionName: Output<String>? = null

    /**
     * @param value A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("qcpuwleccxfywvje")
    public suspend fun actionDefinition(`value`: Output<FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs>) {
        this.actionDefinition = value
    }

    /**
     * @param value A friendly name of the custom action.
     */
    @JvmName("octjutbbqwtprppb")
    public suspend fun actionName(`value`: Output<String>) {
        this.actionName = value
    }

    /**
     * @param value A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("gmfuedaracospoll")
    public suspend fun actionDefinition(`value`: FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionDefinition = mapped
    }

    /**
     * @param argument A configuration block describing the custom action associated with the `action_name`. See Action Definition below for details.
     */
    @JvmName("cgqcagyfpafusivx")
    public suspend fun actionDefinition(argument: suspend FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped =
            FirewallPolicyFirewallPolicyStatelessCustomActionActionDefinitionArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.actionDefinition = mapped
    }

    /**
     * @param value A friendly name of the custom action.
     */
    @JvmName("pwlcugmaqpaesrjq")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionName = mapped
    }

    internal fun build(): FirewallPolicyFirewallPolicyStatelessCustomActionArgs =
        FirewallPolicyFirewallPolicyStatelessCustomActionArgs(
            actionDefinition = actionDefinition ?: throw PulumiNullFieldException("actionDefinition"),
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
        )
}
